from django_rtk.validators import Validator as BaseValidator
from django_rtk_later.validators import Validator as RegisterValidator
from django_rtk_magic_link.validators import Validator as MagicLinkValidator
from django_rtk_password.validators import Validator as PasswordValidator


class Validator(
    BaseValidator, MagicLinkValidator, PasswordValidator, RegisterValidator
):
    pass



from django_rtk_later.backends import Backend as RegisterBackend
from django_rtk_magic_link.backends import Backend as MagicLinkBackend
from django_rtk_password.backends import Backend as PasswordBackend


class Backend(MagicLinkBackend, PasswordBackend, RegisterBackend):
    pass



import graphene
from django_rtk.mutations import ObtainJSONWebToken
from django_rtk_later.mutations import ActivateAccount  # noqa
from django_rtk_later.mutations import RegisterAccount  # noqa
from django_rtk_later.mutations import Mutation as RegisterMutation
from django_rtk_magic_link.mutations import Mutation as MagicLinkMutation
from django_rtk_magic_link.mutations import RequestMagicLink  # noqa
from django_rtk_magic_link.mutations import SignInByMagicLink  # noqa
from django_rtk_password.mutations import ChangePassword  # noqa
from django_rtk_password.mutations import RequestPasswordReset  # noqa
from django_rtk_password.mutations import ResetPassword  # noqa
from django_rtk_password.mutations import Mutation as PasswordMutation


class Mutation(
    MagicLinkMutation, PasswordMutation, RegisterMutation, graphene.ObjectType
):
    token_auth = ObtainJSONWebToken.Field()



import graphene
from django_rtk.queries import Me
from django_rtk_later.queries import Query as RegisterQuery
from django_rtk_magic_link.queries import Query as MagicLinkQuery
from django_rtk_password.queries import Query as PasswordQuery


class Query(Me, MagicLinkQuery, PasswordQuery, RegisterQuery, graphene.ObjectType):
    pass
